"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var tree_component_1 = require("../tree/tree.component");
var _ = require("lodash");
var SelectComponent = (function () {
    function SelectComponent(renderer, cdr) {
        this.renderer = renderer;
        this.cdr = cdr;
        this._treeParams = {
            treeDatas: null,
            keyId: null,
            keyName: null,
            keyChild: null,
            defaultCheckedNodes: null,
            defaultSelectedNode: null,
            options: null
        };
        this.treeCheckEvent = new core_1.EventEmitter();
        this.treeCheckData = new core_1.EventEmitter();
        this.treeClickEvent = new core_1.EventEmitter();
        this.changeValueEvent = new core_1.EventEmitter();
        this.selectBlurEvent = new core_1.EventEmitter();
        this.showThis = false;
        this.isFocus = false;
        this.maxHeight = this.maxHeight || '300px';
        this.width = this.width || '150px';
    }
    Object.defineProperty(SelectComponent.prototype, "currentSelect", {
        get: function () {
            return this._currentSelect;
        },
        set: function (v) {
            var _this = this;
            this._currentSelect = _.cloneDeep(v);
            if (!this.optionList) {
                return;
            }
            var result = this.optionList.find(function (item) {
                if (_this.currentSelect) {
                    return _this.currentSelect[_this.displayField] === item[_this.displayField];
                }
            });
            this.currentValue = result && (result[this.displayField] || result);
        },
        enumerable: true,
        configurable: true
    });
    SelectComponent.prototype.ngOnInit = function () {
        if (this.isTree) {
            this.treeParams.options.checkbox = this.isMultiple;
            this.treeParams.options.actionBtn = false;
            Object.assign(this._treeParams, this.treeParams);
        }
    };
    SelectComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this._treeParams.defaultCheckedNodes && !_.isEmpty(this._treeParams.defaultCheckedNodes)) {
            var result = this._treeParams.defaultCheckedNodes.map(function (value) { return _this.tree.matchSearchNodesByKey(value, _this._treeParams.keyId)[0]; });
            this.currentValue = this.arrStringJoin(result);
        }
        if (this._treeParams.defaultSelectedNode && !_.isEmpty(this._treeParams.defaultSelectedNode)) {
            var result = this.tree.matchSearchNodesByKey(this._treeParams.defaultSelectedNode[this._treeParams.keyId], this._treeParams.keyId);
            if (result && result.length > 0) {
                this.currentValue = result[0][this.displayField];
            }
        }
        this.cdr.detectChanges();
    };
    SelectComponent.prototype.searchTree = function (ev) {
        this.tree.fuzzySearchNodesByKey(ev, this._treeParams.keyName);
    };
    SelectComponent.prototype.changeCurrentValue = function () {
        var _this = this;
        var result = this.optionList.find(function (item) { return _this.currentSelect === item; });
        this.currentValue = result && (result[this.displayField] || result);
    };
    SelectComponent.prototype.onDocumentClick = function (event) {
        if (!this.disable) {
            if (event.target !== this.inputSelect.nativeElement &&
                event.target !== this.dropBtn.nativeElement &&
                event.target.parentNode !== this.dropBtn.nativeElement) {
                if (this.dropList.nativeElement.style.display == 'none') {
                    return;
                }
                this.dropList.nativeElement.style.display = 'none';
                this.isFocus = false;
                if (this.keyword !== undefined) {
                    this.currentValue = this.keyword;
                    this.keyword = undefined;
                }
            }
            else {
                var elm = this.dropList.nativeElement;
                if (event.target === this.dropBtn.nativeElement ||
                    event.target.parentNode === this.dropBtn.nativeElement) {
                    elm.style.display = elm.style.display === 'block' ? 'none' : 'block';
                    this.isFocus = !this.isFocus;
                }
                else {
                    if (this.tree) {
                        var result = [];
                        if (this.isMultiple) {
                            result = this.tree.getCheckedNodes();
                        }
                        else {
                            if (this.tree.getSelectedNodes()) {
                                result = [this.tree.getSelectedNodes()];
                            }
                        }
                        this.keyword = this.arrStringJoin(result);
                    }
                    elm.style.display = 'block';
                    this.isFocus = true;
                }
            }
        }
    };
    SelectComponent.prototype.filter = function (data, keyword) {
        var _this = this;
        if (!this.isReadonly && keyword) {
            return data.filter(function (item) { return item[_this.displayField].indexOf(keyword) > -1; });
        }
        else {
            return data || [];
        }
    };
    SelectComponent.prototype.blurEvent = function (ev) {
        this.selectBlurEvent.emit({
            current: this.currentValue,
            val: this.keyword
        });
    };
    SelectComponent.prototype.confirm = function () {
        var _this = this;
        var result = this.optionList.filter(function (item) { return item[_this.displayField].indexOf(_this.keyword) > -1; });
        if (result && result.length === 1) {
            this.dropList.nativeElement.style.display = 'none';
            this.inputSelect.nativeElement.blur();
            this.currentValue = result[0][this.displayField] || result[0];
            this.keyword = '';
            this.isFocus = false;
        }
    };
    SelectComponent.prototype.changeValue = function (option) {
        var value = option[this.outputField] || option;
        this.currentValue = option[this.displayField] || option;
        this.keyword = undefined;
        this.changeValueEvent.emit(value);
    };
    SelectComponent.prototype.trackByIndex = function (index, value) {
        return index;
    };
    SelectComponent.prototype.treeCheck = function (event) {
        // if (result.length === 1 && event.hasOwnProperty(this._treeParams.keyChild) && event[this._treeParams.keyChild].length > 0) {
        //   this.keyword = event[this.displayField];
        // } else {
        var result = this.tree.getCheckedNodes();
        this.keyword = this.arrStringJoin(result);
        // }
        this.treeCheckEvent.emit(event);
        this.treeCheckData.emit(result);
    };
    SelectComponent.prototype.treeClick = function (event) {
        if (event) {
            this.keyword = event[this.displayField];
            this.treeClickEvent.emit(event);
        }
        else {
            this.keyword = '';
            this.treeClickEvent.emit(null);
        }
    };
    SelectComponent.prototype.arrStringJoin = function (arr) {
        var _this = this;
        if (arr && arr.length == 0) {
            return '';
        }
        var str = arr.map(function (item) { return item[_this.displayField]; });
        return str.length > 1 ? str.join(',') : str[0];
    };
    SelectComponent.prototype.getSelectVal = function () {
        var res;
        if (this.isMultiple) {
            res = this.tree.getCheckedNodes();
        }
        else {
            res = this.tree.getSelectedNodes();
        }
        return res;
    };
    SelectComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'dc-select',
                    template: "\n    <div class=\"dc-select-container\" [ngClass]=\"{'disable':disable}\" [style.width]=\"width\">\n      <div class=\"dc-select-input\" title=\"{{currentValue}}\">\n        <input name=\"dcSelect\" [(ngModel)]=\"keyword\" [disabled]=\"disable\" [readonly]=\"isReadonly || isTree\"\n               (keyup.enter)=\"confirm()\" (blur)=\"blurEvent()\" #inputSelect>\n        <span [hidden]=\"(keyword && keyword.length>0) || isFocus\">{{currentValue}}</span>\n        <div class=\"dc-select-btn\" #dropBtn>\n          <div class=\"dc-select-arrow\"></div>\n        </div>\n      </div>\n      <ul *ngIf=\"!isTree\" class=\"dc-select-drop\" #dropList [style.maxHeight]=\"maxHeight\">\n        <li *ngFor=\"let option of filter(optionList, keyword); let i = index; trackBy: trackByIndex\"\n            (click)=\"changeValue(option)\" [class.selected]=\"currentValue==option[displayField]\">{{option[displayField] || option}}\n        </li>\n        <div *ngIf=\"filter(optionList, keyword).length == 0\" style=\"text-align: center; height: 30px; line-height: 30px;\">No Data.</div>\n      </ul>\n      <div (click)=\"$event.stopPropagation()\" style=\"padding: 10px 0;\" *ngIf=\"isTree && isMultiple && _treeParams.treeDatas\"\n           class=\"dc-select-drop\" #dropList>\n        <div *ngIf=\"treeSearch\">\n          <dc-search [width]=\"'100%'\" (search)=\"searchTree($event)\"></dc-search>\n        </div>\n        <div [style.maxHeight]=\"maxHeight\">\n          <dc-tree [treeDatas]=\"_treeParams.treeDatas\" [keyId]=\"_treeParams.keyId\" [keyName]=\"_treeParams.keyName\"\n                   [defaultCheckedNodes]=\"_treeParams.defaultCheckedNodes\" [keyChild]=\"_treeParams.keyChild\" [options]=\"_treeParams.options\"\n                   (checkEvent)=\"treeCheck($event)\" #tree></dc-tree>\n        </div>\n      </div>\n      <div (click)=\"$event.stopPropagation()\" style=\"padding: 10px 0;\" *ngIf=\"isTree && !isMultiple && _treeParams.treeDatas\"\n           class=\"dc-select-drop\" #dropList>\n        <div *ngIf=\"treeSearch\" (click)=\"$event.stopPropagation()\">\n          <dc-search [width]=\"'100%'\" (search)=\"searchTree($event)\"></dc-search>\n        </div>\n        <div [style.maxHeight]=\"maxHeight\">\n          <dc-tree [treeDatas]=\"_treeParams.treeDatas\" [keyId]=\"_treeParams.keyId\" [keyName]=\"_treeParams.keyName\"\n                   [defaultSelectedNode]=\"_treeParams.defaultSelectedNode\" [keyChild]=\"_treeParams.keyChild\" [options]=\"_treeParams.options\"\n                   (clickEvent)=\"treeClick($event)\" #tree></dc-tree>\n        </div>\n      </div>\n    </div>",
                    styles: [
                        ".dc-select-container {\n      width: 160px;\n      height: 30px;\n      font-size: 14px;\n      color: #333;\n      background: #fff;\n      border: solid 1px #ccc;\n      border-radius: 3px;\n      margin: 0 10px;\n      padding: 0;\n      display: inline-block;\n      position: relative\n    }\n\n    .dc-select-container:hover {\n      border-color: #3d70b2\n    }\n\n    .dc-select-container:active {\n      border-color: #0081cc\n    }\n\n    .dc-select-container.disable {\n      background: #f5f5f5;\n      border-color: #ccc;\n      color: #999\n    }\n\n    .dc-select-input {\n      padding: 5px 10px;\n      width: 100%;\n      height: 30px;\n      position: relative;\n    }\n\n    .dc-select-input > input {\n      outline: none;\n      border: none;\n      width: 90%;\n      height: 18px;\n      line-height: 18px;\n      background: none;\n      position: relative;\n      z-index: 1;\n    }\n\n    .dc-select-input > input:read-only {\n      cursor: default\n    }\n\n    .dc-select-input > span {\n      display: block;\n      position: absolute;\n      width: 78%;\n      height: 18px;\n      left: 10px;\n      top: 5px;\n      line-height: 18px;\n      overflow: hidden;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      z-index: 0;\n    }\n\n    .dc-select-btn {\n      width: 0;\n      height: 30px;\n      position: absolute;\n      right: 0;\n      top: 0;\n      padding: 12px 20px 0 10px;\n      cursor: pointer;\n    }\n\n    .dc-select-container.disable .dc-select-btn {\n      cursor: default;\n    }\n\n    .dc-select-arrow {\n      border: solid 4px transparent;\n      border-top-width: 6px;\n      border-top-color: #333;\n      width: 0;\n      height: 0;\n    }\n\n    .dc-select-container.disable .dc-select-arrow {\n      border-top-color: #ccc;\n    }\n\n    .dc-select-drop {\n      position: absolute;\n      top: 30px;\n      left: -1px;\n      width: calc(100% + 2px);\n      box-shadow: 0px 0px 10px 2px rgba(0, 0, 0, .2);\n      background: #fff;\n      list-style: none;\n      border-radius: 3px;\n      overflow-y: auto;\n      overflow-x: hidden;\n      display: none;\n      z-index: 1000;\n    }\n\n    .selected {\n      background-color: #0081cc;\n      color: #ffffff;\n    }\n\n    .dc-select-drop > li {\n      width: 100%;\n      height: 30px;\n      line-height: 26px;\n      cursor: pointer;\n      overflow: hidden;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      padding: 0 11px\n    }\n\n    .dc-select-drop > li:hover {\n      color: #333333;\n      background: #edf0f5;\n    }\n\n    .dc-select-drop > li.selected {\n      background-color: #0081cc;\n      color: #ffffff;\n    }"
                    ]
                },] },
    ];
    /** @nocollapse */
    SelectComponent.ctorParameters = function () { return [
        { type: core_1.Renderer, },
        { type: core_1.ChangeDetectorRef, },
    ]; };
    SelectComponent.propDecorators = {
        "optionList": [{ type: core_1.Input },],
        "disable": [{ type: core_1.Input },],
        "treeSearch": [{ type: core_1.Input },],
        "isReadonly": [{ type: core_1.Input },],
        "displayField": [{ type: core_1.Input },],
        "outputField": [{ type: core_1.Input },],
        "width": [{ type: core_1.Input },],
        "maxHeight": [{ type: core_1.Input },],
        "isMultiple": [{ type: core_1.Input },],
        "isTree": [{ type: core_1.Input },],
        "treeParams": [{ type: core_1.Input },],
        "treeCheckEvent": [{ type: core_1.Output },],
        "treeCheckData": [{ type: core_1.Output },],
        "treeClickEvent": [{ type: core_1.Output },],
        "changeValueEvent": [{ type: core_1.Output },],
        "selectBlurEvent": [{ type: core_1.Output },],
        "inputSelect": [{ type: core_1.ViewChild, args: ['inputSelect',] },],
        "dropBtn": [{ type: core_1.ViewChild, args: ['dropBtn',] },],
        "dropList": [{ type: core_1.ViewChild, args: ['dropList',] },],
        "tree": [{ type: core_1.ViewChild, args: ['tree',] },],
        "currentSelect": [{ type: core_1.Input },],
        "onDocumentClick": [{ type: core_1.HostListener, args: ['document:click', ['$event'],] },],
    };
    return SelectComponent;
}());
exports.SelectComponent = SelectComponent;
//# sourceMappingURL=select.component.js.map